|PyPI version| |image1| |Downloads| |image3| |Coverage Status| |image5|
|Build Status|

Omblog is a django based blog system designed to have a smooth, minimal
writing experience so it's a joy to use and be heavily cached so it can
take a battering.

It is currently being worked on after a long break, however please be
aware that at this current time there is no default frontend skin for
displaying your posts, there is only the UI for creating / editing.

`The documentation will help you get
started <http://django-omblog.readthedocs.org/>`__

If you're looking for a blog that you can style to death that can take a
battering, then give omblog a try.

.. figure:: http://django-omblog.readthedocs.org/en/latest/_images/create-3.png
   :alt: The writing UI

   The writing UI
Current Features
----------------

-  Minimal UI for writing posts
-  Drag and drop image uploading with automatic thumbnailing
-  Syntax highlighting
-  Keyboard shortcut to save posts
-  Tab key inserts 4 spaces and doesn't bounce out of the writingarea.
-  If you have Django's cache backend configured, it can take a
   battering.

Credits
-------

The following libraries / plugins are included in omblog; many thanks is
extended to the authors for their fine, fine work.

-  `jQuery <http://jquery.com/>`__
-  `ICanHaz.js <http://icanhazjs.com/>`__
-  `jquery.autosize.js <https://github.com/jackmoore/autosize>`__
-  `mousetrap.js <http://craig.is/killing/mice>`__
-  `jquery.slugify <http://patrickmcelhaney.com/jQuery-Slugify-Plugin/>`__
-  `django-thumbs <https://pypi.python.org/pypi/django-thumbs>`__

|Bitdeli Badge|

.. |PyPI version| image:: https://badge.fury.io/py/django-omblog.png
   :target: http://badge.fury.io/py/django-omblog
.. |image1| image:: https://obscure-misc.s3.amazonaws.com/spacer.png
.. |Downloads| image:: https://pypip.in/d/django-omblog/badge.png
.. |image3| image:: https://obscure-misc.s3.amazonaws.com/spacer.png
.. |Coverage Status| image:: https://coveralls.io/repos/jamiecurle/django-omblog/badge.png?branch=develop
   :target: https://coveralls.io/r/jamiecurle/django-omblog
.. |image5| image:: https://obscure-misc.s3.amazonaws.com/spacer.png
.. |Build Status| image:: https://jenkins.curle.io/buildStatus/icon?job=django-omblog-django-1.6.1
.. |Bitdeli Badge| image:: https://d2weczhvl823v0.cloudfront.net/jamiecurle/django-omblog/trend.png
   :target: https://bitdeli.com/free
